@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: slon.c,v 1.66.2.3 2006/11/14 17:24:20 wieck Exp $
+ *	$Id: slon.c,v 1.66.2.7 2007-07-20 19:53:25 cbbrowne Exp $
  *-------------------------------------------------------------------------
  */
 
@@ -27,6 +27,7 @@
 #ifdef WIN32
 #include <winsock2.h>
 #include "port/win32service.h"
+#define sleep(x) Sleep(x*1000)
 #endif
 
 #include "libpq-fe.h"
@@ -93,6 +94,8 @@ Usage(char *const argv[])
 	fprintf(stderr, "\n");
 	fprintf(stderr, "Options:\n");
 
+	fprintf(stderr, "    -h                    print usage message and exit\n");
+	fprintf(stderr, "    -v                    print version and exit\n");
 	fprintf(stderr, "    -d <debuglevel>       verbosity of logging (1..4)\n");
 	fprintf(stderr, "    -s <milliseconds>     SYNC check interval (default 10000)\n");
 	fprintf(stderr, "    -t <milliseconds>     SYNC interval timeout (default 60000)\n");
@@ -327,7 +330,7 @@ main(int argc, char *const argv[])
 		}
 		else
 		{
-			slon_log(SLON_FATAL, "Cannot open pid_file \"%s\", pid_file\n");
+			slon_log(SLON_FATAL, "Cannot open pid_file \"%s\"\n", pid_file);
 			exit(-1);
 		}
 	}
@@ -392,15 +395,17 @@ SlonMain(void)
 	startup_conn = PQconnectdb(rtcfg_conninfo);
 	if (startup_conn == NULL)
 	{
-		slon_log(SLON_FATAL, "main: PQconnectdb() failed\n");
+		slon_log(SLON_FATAL, "main: PQconnectdb() failed - sleep 10s\n");
+		sleep (10);
 		slon_retry();
 		exit(-1);
 	}
 	if (PQstatus(startup_conn) != CONNECTION_OK)
 	{
-		slon_log(SLON_FATAL, "main: Cannot connect to local database - %s\n",
+		slon_log(SLON_FATAL, "main: Cannot connect to local database - %s - sleep 10s\n",
 				 PQerrorMessage(startup_conn));
 		PQfinish(startup_conn);
+		sleep(10);
 		slon_retry();
 		exit(-1);
 	}
@@ -411,7 +416,8 @@ SlonMain(void)
 	rtcfg_nodeid = db_getLocalNodeId(startup_conn);
 	if (rtcfg_nodeid < 0)
 	{
-		slon_log(SLON_FATAL, "main: Node is not initialized properly\n");
+		slon_log(SLON_FATAL, "main: Node is not initialized properly - sleep 10s\n");
+		sleep(10);
 		slon_retry();
 		exit(-1);
 	}
@@ -469,8 +475,9 @@ SlonMain(void)
 				 "set transaction isolation level serializable;");
 	if (PQresultStatus(res) != PGRES_COMMAND_OK)
 	{
-		slon_log(SLON_FATAL, "Cannot start transaction - %s\n",
+		slon_log(SLON_FATAL, "Cannot start transaction - %s - sleep 10s\n",
 				 PQresultErrorMessage(res));
+		sleep (10);
 		PQclear(res);
 		slon_retry();
 	}
@@ -951,7 +958,8 @@ slon_terminate_worker()
 		kill(slon_worker_pid, SIGKILL);
 		slon_exit(-1);
 	}
-
+        close(sched_wakeuppipe[0]);
+	close(sched_wakeuppipe[1]);
 	alarm(20);
 }
 #endif
