@@ -6,27 +6,26 @@
  *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: slonik.c,v 1.67.2.6 2007-03-15 18:52:02 cbbrowne Exp $
+ *	$Id: slonik.c,v 1.67.2.13 2008-01-08 20:42:41 cbbrowne Exp $
  *-------------------------------------------------------------------------
  */
 
 
+#ifndef WIN32
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
-#ifndef WIN32
 #include <unistd.h>
 #include <fcntl.h>
 #include <ctype.h>
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <errno.h>
+#include <time.h>
 #else
 #define sleep(x) Sleep(x*1000)
 #define vsnprintf _vsnprintf
-#define INT64_FORMAT "%I64d"
 #endif
-#include <errno.h>
-#include <time.h>
 
 #include "postgres.h"
 #include "libpq-fe.h"
@@ -43,9 +42,7 @@ SlonikScript *parser_script = NULL;
 int			parser_errors = 0;
 int			current_try_level;
 
-#ifdef WIN32
 static char myfull_path[MAXPGPATH];
-#endif
 static char share_path[MAXPGPATH];
 
 /*
@@ -105,22 +102,19 @@ main(int argc, const char *argv[])
 
 	if (parser_errors)
 		usage();
-#ifndef WIN32
-        strcpy(share_path, PGSHARE);
-#else
+
 	/*
 	 * We need to find a share directory like PostgreSQL. 
 	 */
 	if (find_my_exec(argv[0],myfull_path) < 0)
 	{
-		printf("full path was unacquirable. '%s'\n", argv[0]);
-		return -1;
+		strcpy(share_path, PGSHARE);
 	}
 	else
 	{
 		get_share_path(myfull_path, share_path);
 	}
-#endif
+
 	if (optind < argc)
 	{
 		while (optind < argc)
@@ -1887,7 +1881,7 @@ load_slony_base(SlonikStmt * stmt, int no_id)
 		use_major = 8;
 		use_minor = 0;
 	}
-	else if ((adminfo->pg_version >= 80100) && adminfo->pg_version < 80300)	/* 8.1 and 8.2 */
+	else if ((adminfo->pg_version >= 80100) && adminfo->pg_version < 80400)	/* 8.1, 8.2 and 8.3 */
 	{
 		use_major = 8;
 		use_minor = 1;
@@ -3849,13 +3843,18 @@ slonik_ddl_script(SlonikStmt_ddl_script * stmt)
 	PGresult *res;
 	ExecStatusType rstat;
 
+
 #define PARMCOUNT 1  
 
         const char *params[PARMCOUNT];
         int paramlens[PARMCOUNT];
         int paramfmts[PARMCOUNT];
 
-	adminfo1 = get_active_adminfo((SlonikStmt *) stmt, stmt->ev_origin);
+	if(stmt->only_on_node > -1) {
+		adminfo1 = get_active_adminfo((SlonikStmt*) stmt,stmt->only_on_node);
+	} else {
+		adminfo1 = get_active_adminfo((SlonikStmt *) stmt, stmt->ev_origin);
+	}
 	if (adminfo1 == NULL)
 		return -1;
 
@@ -3882,6 +3881,7 @@ slonik_ddl_script(SlonikStmt_ddl_script * stmt)
 	slon_mkquery(&query,
 		     "select \"_%s\".ddlScript_prepare(%d, %d); ",
 		     stmt->hdr.script->clustername,
+
 		     stmt->ddl_setid, /* dstring_data(&script),  */ 
 		     stmt->only_on_node);
 
@@ -3916,7 +3916,7 @@ slonik_ddl_script(SlonikStmt_ddl_script * stmt)
 		}
 		strncpy(dest, dstring_data(&script) + startpos, endpos-startpos);
 		dest[STMTS[stmtno]-startpos] = 0;
-		slon_mkquery(&query, dest);
+		slon_mkquery(&query, "%s", dest);
 		printf("DDL Statement %d: (%d,%d) [%s]\n", stmtno, startpos, endpos, dest);
 		free(dest);
 
@@ -3929,39 +3929,59 @@ slonik_ddl_script(SlonikStmt_ddl_script * stmt)
 			rstat = PQresultStatus(res);
 			printf("DDL Statement failed - %s\n", PQresStatus(rstat));
 			dstring_free(&query);
+			PQclear(res);
 			return -1;
 		}
 		/* rstat = PQresultStatus(res); */
 		/* printf ("Success - %s\n", PQresStatus(rstat)); */
+
+		PQclear(res);
 	}
 	
-	printf("Submit DDL Event to subscribers...\n");
-
+	printf("Complete DDL Event...\n");
+	
 	slon_mkquery(&query, "select \"_%s\".ddlScript_complete(%d, $1::text, %d); ", 
-		     stmt->hdr.script->clustername,
-		     stmt->ddl_setid,  
-		     stmt->only_on_node);
-
+				 stmt->hdr.script->clustername,
+				 stmt->ddl_setid,  
+				 stmt->only_on_node);
+	
 	paramlens[PARMCOUNT-1] = 0;
 	paramfmts[PARMCOUNT-1] = 0;
 	params[PARMCOUNT-1] = dstring_data(&script);
-
-	res = PQexecParams(adminfo1->dbconn, dstring_data(&query), PARMCOUNT,
-			   NULL, params, paramlens, paramfmts, 0);
 	
-	if (PQresultStatus(res) != PGRES_COMMAND_OK && 
-	    PQresultStatus(res) != PGRES_TUPLES_OK &&
-	    PQresultStatus(res) != PGRES_EMPTY_QUERY)
+	res = PQexecParams(adminfo1->dbconn, dstring_data(&query), PARMCOUNT,
+					   NULL, params, paramlens, paramfmts, 0);
+	
+	/*
+	 * Check that the event submission returned exactly one result row
+	 */
+	if (PQresultStatus(res) != PGRES_TUPLES_OK)
 	{
 		rstat = PQresultStatus(res);
 		printf("Event submission for DDL failed - %s\n", PQresStatus(rstat));
+		dstring_free(&script);
 		dstring_free(&query);
+		PQclear(res);
 		return -1;
-	} else {
-		rstat = PQresultStatus(res);
-		printf ("DDL on origin - %s\n", PQresStatus(rstat));
 	}
-	
+	if (PQntuples(res) != 1)
+	{
+		printf("Event submission for DDL failed - query returned %d rows (expected 1)\n", PQntuples(res));
+		dstring_free(&script);
+		dstring_free(&query);
+		PQclear(res);
+		return -1;
+	}
+
+	/*
+	 * ... which should be the event-seqno for the DDL_SCRIPT event.
+	 * We remember that in the admin conninfo for WAIT.
+	 */
+	slon_scanint64(PQgetvalue(res, 0, 0), &(adminfo1->last_event));
+
+	rstat = PQresultStatus(res);
+	PQclear(res);
+	printf ("DDL submission to initial node - %s\n", PQresStatus(rstat));
 	dstring_free(&script);
 	dstring_free(&query);
 	return 0;
@@ -4230,7 +4250,7 @@ slonik_sync(SlonikStmt_sync * stmt)
 				 "select \"_%s\".createEvent('_%s', 'SYNC'); ",
 				 stmt->hdr.script->clustername,
 				 stmt->hdr.script->clustername);
-	if (db_exec_command((SlonikStmt *) stmt, adminfo1, &query) < 0)
+	if (db_exec_evcommand((SlonikStmt *) stmt, adminfo1, &query) < 0)
 	{
 		dstring_free(&query);
 		return -1;
